@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pet" "4.0.0"
+(define-package "pet" "20250803.1832"
   "Executable and virtualenv tracker for python-mode."
   '((emacs "27.1")
     (f     "0.6.0")
